@@ -15,6 +15,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from ansible.plugins.lookup import LookupBase
+from tripleo_validations import utils
+
 DOCUMENTATION = """
     lookup: ironic_nodes
     description: Retrieve node information from Ironic
@@ -42,10 +45,22 @@ EXAMPLES = """
     - name: Get all nodes for a set of instance UUIDs
       debug:
         msg: |
-             {{ lookup(''ironic_nodes', 'instance_uuid',
+             {{ lookup('ironic_nodes', 'instance_uuid',
              ['1691a1c7-9974-4bcc-a07a-5dec7fc04da0',
              '07f2435d-820c-46ce-9097-cf8a7282293e'],
              wantlist=True) }}"
+
+    - name: Get all nodes marked as 'associated'
+      debug:
+        msg: |
+             {{ lookup('ironic_nodes', 'associated',
+             wantlist=True) }}"
+
+    - name: Get nodes in provision state, and not associated or in maintenance
+      debug:
+        msg: |
+             {{ lookup('ironic_nodes', 'provision_state',
+             ['available', 'inspect'], wantlist=True)}}
 """
 
 RETURN = """
@@ -53,26 +68,12 @@ _raw:
     description: A Python list with results from the API call.
 """
 
-from ansible.plugins.lookup import LookupBase
-from ironicclient import client as ironic_client
-
-from tripleo_validations import utils
-
 
 class LookupModule(LookupBase):
 
     def run(self, terms, variables=None, **kwargs):
         """Returns node information from ironic."""
-        auth_url = variables.get('auth_url')
-        username = variables.get('username')
-        project_name = variables.get('project_name')
-        token = variables.get('os_auth_token')
-        session = utils.get_auth_session(auth_url, username, project_name,
-                                         auth_token=token)
-        ironic_url = session.get_endpoint(service_type='baremetal',
-                                          interface='public')
-        ironic = ironic_client.get_client(1, ironic_url=ironic_url,
-                                          os_auth_token=token)
+        ironic = utils.get_ironic_client(variables)
 
         if len(terms) > 0:
             if terms[0] == 'id':
@@ -82,6 +83,18 @@ class LookupModule(LookupBase):
                 nodes = [ironic.node.get_by_instance_uuid(uuid)
                          for uuid in terms[1]]
                 return [utils.filtered(node) for node in nodes]
+            elif terms[0] == 'associated':
+                nodes = ironic.node.list(associated=True, detail=True)
+                return [utils.filtered(node) for node in nodes]
+            elif terms[0] == 'provision_state':
+                nodes = []
+                for term in terms[1]:
+                    nodes.extend(ironic.node.list(
+                        provision_state=term,
+                        associated=False,
+                        maintenance=False,
+                        detail=True))
+                return [utils.filtered(node) for node in nodes]
         else:
             return [utils.filtered(node)
                     for node in ironic.node.list(detail=True)]
